==> parodia_admin-1.0.2.tar.gz: lib/core/repository/profile.repository.dart <==
// GET
// /api/v1/dashboard/profile

// PUT
// /api/v1/dashboard/profile

// DELETE
// /api/v1/dashboard/profile

// PUT
// /api/v1/dashboard/profile/password

// PUT
// /api/v1/dashboard/profile/email

import 'package:parodia_admin/core/dto/profile.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';

class ProfileRepository {
  ParodiaHTTP? _http;

  ProfileRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProfileDTO>> get() async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/profile',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({
    ProfilePutBody? profile,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/profile',
      data: profile,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete() async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/profile',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> updatePassword({
    ProfilePasswordChangeBody? profilePassword,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/profile/password',
      data: profilePassword,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> updateEmail({
    ProfileEmailChangeBody? profileEmail,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/profile/email',
      data: profileEmail,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.5.tar.gz: lib/core/repository/profile.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/profile

// PUT
// /api/v1/dashboard/dashboard/profile

// DELETE
// /api/v1/dashboard/dashboard/profile

// PUT
// /api/v1/dashboard/dashboard/profile/password

// PUT
// /api/v1/dashboard/dashboard/profile/email

import 'package:parodia_admin/core/dto/profile.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';

class ProfileRepository {
  ParodiaHTTP? _http;

  ProfileRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProfileDTO>> get() async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/profile',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({
    ProfilePutBody? profile,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/profile',
      data: profile,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete() async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/profile',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> updatePassword({
    ProfilePasswordChangeBody? profilePassword,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/profile/password',
      data: profilePassword,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> updateEmail({
    ProfileEmailChangeBody? profileEmail,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/profile/email',
      data: profileEmail,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
